@@ -8,6 +8,8 @@ from ..utils.regex import RE_MODIFIER
 if TYPE_CHECKING:
     from ..awesomeversion import AwesomeVersion
 
+MODIFIERS = {"rc": 3, "beta": 2, "b": 2, "alpha": 1, "a": 1, "dev": 0, "d": 0}
+
 
 def compare_handler_sections(
     version_a: AwesomeVersion,
@@ -46,7 +48,7 @@ def compare_modifier_section(
     version_a: AwesomeVersion,
     version_b: AwesomeVersion,
 ) -> bool | None:
-    """Compare sections between two AwesomeVersion objects."""
+    """Compare modifiers between two AwesomeVersion objects."""
     if version_a.modifier is not None and version_b.modifier is not None:
         version_a_modifier = RE_MODIFIER.match(version_a.string.split(".")[-1])
         version_b_modifier = RE_MODIFIER.match(version_b.string.split(".")[-1])
@@ -55,5 +57,9 @@ def compare_modifier_section(
                 return int(version_a_modifier.group(4)) > int(
                     version_b_modifier.group(4)
                 )
-            return version_a_modifier.group(3) > version_b_modifier.group(3)
+            mod_a = MODIFIERS.get(version_a_modifier.group(3))
+            mod_b = MODIFIERS.get(version_b_modifier.group(3))
+            if mod_a is not None and mod_b is not None:
+                return mod_a > mod_b
+            return version_a_modifier.group(3) > version_a_modifier.group(3)
     return None
